<!-- SPDX-License-Identifier: CC-BY-4.0 -->
<!-- Copyright Contributors to the Egeria project. -->

# Personal Organizer

These widgets display different kinds of information about the projects, tasks and todos. Widgets
will continue to be added over time to cover more facets of catalog use.

* get_my_profiles.py - gets profile information about an individual.
* list_projects.py - lists information about a specified project or projects containing the search string.
* list_todos.py - lists information about a specified todo item or all todos containing the search string
* view_my_todos.py - view live status information about an individual's todos.
* view_open_todos.py - view live status information about open todos.

----
License: [CC BY 4.0](https://creativecommons.org/licenses/by/4.0/),
Copyright Contributors to the Egeria project.